import moment from "moment";
import CommonServer from "./common";
import axios from "axios";
import { ElMessage } from "element-plus";

// 文件扩展名提取
export const fileType = fileName => {
  fileName.substring(fileName.lastIndexOf(".") + 1);
};

/**
 * oss 路径定义
 * @param file 文件
 * @param customFileType 自定义扩展名
 */
export const ossPath = (file, customFileType) => {
  const folder = moment().format("YYYY-MM-DD");
  const name = moment().format("YYYY-MM-DD-HH-mm-ss-SSS");

  if (file.name) {
    const type = fileType(file.name);
    return `项目名称(金山云上创建的对应项目文件名/upload/${folder}/${type}/${name}.${type})`;
  } else if (customFileType) {
    return `项目名称(金山云上创建的对应项目文件名/upload/${folder}/${customFileType}/${name}.${customFileType})`;
  }
};

/**
 * 金山云上传
 * @returns {Promise<any>}
 */
export const ksOssUpload = (file, customFileType) => {
  return new Promise((resolve, reject) => {
    const key = ossPath(file, customFileType);
    const params = { fileName: key };
    CommonServer.getKsOssSign(params)
      .then(res => {
        const { accessid, policy, signature, host } = res;
        const formData = new FormData();
        formData.append("acl", "public-read");
        formData.append("key", key);
        formData.append("signature", signature);
        formData.append("KSSAccessKeyId", accessid);
        formData.append("policy", policy);
        formData.append("file", file);
        axios
          .post(`https://${host}`, formData)
          .then(res => {
            const { status } = res;
            if (status === 200) {
              const data = {
                url: `https://${host}/${key}`,
                type: file.name ? fileType(file.name) : customFileType
              };
              resolve(data);
            } else {
              reject(res);
            }
          })
          .catch(err => {
            reject(err);
          });
      })
      .catch(err => {
        console.log(err);
      });
  });
};

/**
 * 上传文件大小限制
 * @param file
 * @param fileMaxSize
 * @returns {boolean}
 */
export const isMaxFileSize = (file, fileMaxSize = 1) => {
  if (!file) return false;
  const isMaxSize = file.size / 1024 / 1024 < fileMaxSize;
  if (!isMaxSize) {
    ElMessage.error(`上传文件大小不能超过${fileMaxSize}MB!`);
    return false;
  }
  return true;
};

/**
 * 文件最大数量限制
 * @param fileList
 * @param maxLength
 * @returns {boolean}
 */
export const isMaxFileLength = (fileList = [], maxLength = 3) => {
  if (fileList.length > maxLength) {
    ElMessage.error(`最多上传${maxLength}个文件`);
    return false;
  }
  return true;
};

/**
 * 判断上传是否为图片
 * @param file
 * @returns {boolean}
 */
export const isImageFile = file => {
  if (!file) return false;
  const types = [
    "image/png",
    "image/gif",
    "image/jpeg",
    "image/jpg",
    "image/bmp",
    "image/x-icon"
  ];
  const isImage = types.includes(file.type);
  if (!isImage) {
    ElMessage.error(`上传文件非图片格式`);
    return false;
  }
  return true;
};

/**
 * 判断图片是否损坏
 * @param file
 */
export const isNormalImage = file => {
  return new Promise((resolve, reject) => {
    if (!file) return;
    const image = new Image();
    image.src = file;
    image.onload = () => {
      resolve({ status: 1, message: "加载成功" });
    };
    image.onerror = () => {
      reject({ status: 0, errMsg: "图片损坏,请重新上传" });
    };
  });
};
